pub enum ForceGenesisConfig<T: Config> {
ProbationPeriod(BlockNumberFor<T>),
ReduceProbationBy(BlockNumberFor<T>),
IncreaseProbationBy(BlockNumberFor<T>),
RewardsBuffer(BlockNumberFor<T>),
PenaltiesBuffer(BlockNumberFor<T>),
MaxElected(u32),
MinElected(u32),
EnforceMaxElected(bool),
MinFund(AuthorAsset<T>),
MaxExposure(AuthorAsset<T>),
MinCollateral(AuthorAsset<T>),
}Expand description
Enumerates configurable runtime-stored parameters that influences probation, rewards, penalties, election constraints, or economic limits may be forcibly overridden at runtime through privileged (root/governance) operations.
Variants
ProbationPeriod(BlockNumberFor<T>)
Updates the number of blocks authors must remain in probation.
ReduceProbationBy(BlockNumberFor<T>)
Updates how much probation is reduced on good behavior.
IncreaseProbationBy(BlockNumberFor<T>)
Updates how much probation is increased on misbehavior.
RewardsBuffer(BlockNumberFor<T>)
PenaltiesBuffer(BlockNumberFor<T>)
Updates the delay (in blocks) before penalties are enforced.
MaxElected(u32)
Updates the maximum number of authors that can be elected.
MinElected(u32)
Updates the minimum number of authors required for a valid election.
EnforceMaxElected(bool)
Toggles strict enforcement of MaxElected.
MinFund(AuthorAsset<T>)
Update the minimum funding required per backing operation.
MaxExposure(AuthorAsset<T>)
Updates the maximum allowed exposure per funding operation.
MinCollateral(AuthorAsset<T>)
Updates the minimum collateral required for authors.