pub type BackingElectionWeight<T> = (Funder<T>, AuthorAsset<T>);Expand description
A single backing contribution used in backing-based election.
Pairs a Funder with the asset value attributed to that funder
for election weighting.
pub type BackingElectionWeight<T> = (Funder<T>, AuthorAsset<T>);A single backing contribution used in backing-based election.
Pairs a Funder with the asset value attributed to that funder
for election weighting.