Type Alias ElectedAuthors

pub type ElectedAuthors<T> = Vec<Author<T>>;
A list of authors selected by an election round.

Represents the final election output returned by the configured election model.

Aliased Type

pub struct ElectedAuthors<T> { /* private fields */ }