pub type IndexDigest<T> = <<T as Config>::CommitmentAdapter as Commitment<Author<T>>>::Digest;Expand description
Represents a digest identifier for an indexed commitment (unmanaged pools)
backing an Author role.
pub type IndexDigest<T> = <<T as Config>::CommitmentAdapter as Commitment<Author<T>>>::Digest;Represents a digest identifier for an indexed commitment (unmanaged pools)
backing an Author role.