pub type PoolDigest<T> = <<T as Config>::CommitmentAdapter as Commitment<Author<T>>>::Digest;Expand description
Represents a digest identifier for a pool commitment (managed collective commitment)
funding source for an Author role.
pub type PoolDigest<T> = <<T as Config>::CommitmentAdapter as Commitment<Author<T>>>::Digest;Represents a digest identifier for a pool commitment (managed collective commitment)
funding source for an Author role.