pub type Ratio<T> = <Pallet<T> as CompensateRoles<Author<T>>>::Ratio;Expand description
Penalty ratio type used by the Author Roles subsystem.
pub type Ratio<T> = <Pallet<T> as CompensateRoles<Author<T>>>::Ratio;Penalty ratio type used by the Author Roles subsystem.